@@ -2,7 +2,7 @@ test_that("prefix", {
   # unique table name
   options(og_table_name = 0)
   expect_true(stringr::str_starts(uniqueTableName(), "og_001"))
-  expect_true(stringr::str_starts(uniqueTableName(),"og_002"))
+  expect_true(stringr::str_starts(uniqueTableName(), "og_002"))
   options(og_table_name = 100)
   expect_true(stringr::str_starts(uniqueTableName(), "og_101"))
 
@@ -19,7 +19,9 @@ test_that("prefix", {
   options(tmp_prefix_number = 111)
   expect_no_error(x <- uniqueTableName(tmpPrefix()))
   expect_true(nchar(x) == 25)
-  x <- x |> strsplit(split = "_") |> unlist()
+  x <- x |>
+    strsplit(split = "_") |>
+    unlist()
   expect_true(length(x) == 5)
   expect_true(x[1] == "tmp")
   expect_true(x[2] == "112")
